﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"
                    xalign who_xalign

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu
    
        
init -2 python:
    style.say_label.set_parent('default')
    style.say_label.xalign = 0.5        
    style.say_label.yalign = 0.5
    style.say_label.font = "Leander.ttf"
    style.say_label.outlines = [(4, "#000000")]
    style.say_label.bold = False
    style.say_label.size = 40
        
    style.say_who_window.set_parent('default')
    style.say_who_window.xalign = 0.5
    
    style.say_who_window.ypos = 50
    style.say_who_window.background = None
    

    
##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.85      
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    #style.menu_choice_button.background = Frame("images/choice_box.png", 9,9)
    #style.menu_choice_button.hover_background = Frame("images/choice_box_dark.png", 9,9)
    
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window:
        has vbox

        text prompt
        input id "input"

    use quick_menu
        
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
    
    
init -2 python:
    style.nvl_window.set_parent('default')    
    style.nvl_window.left_margin = 50
    style.nvl_window.right_margin = 50
    style.nvl_window.top_margin = 50
    style.nvl_window.bottom_margin = 50   
    style.nvl_window.background = None
    
    style.nvlchar = Style(style.default)
    style.nvlchar.xalign = 0.0
    style.nvlchar.yalign = 0.0
    style.nvlchar.left_margin = 0
    style.nvlchar.right_margin = 0
    style.nvlchar.bottom_margin = 0
    style.nvlchar.top_margin = 0
    
    style.shortnvl = Style(style.default)
    style.shortnvl.ypos = 100
    style.shortnvl.xpadding = 30
    
    style.nvlleft = Style(style.default)
    style.nvlleft.xalign = 0.0
    style.nvlleft.right_margin = 300
    
    style.nvlbottom = Style(style.default)
    style.nvlbottom.ypos = 420    
    
init python:    
    config.empty_window = nvl_show_core
    config.window_hide_transition = dissolve
    config.window_show_transition = dissolve
    config.nvl_paged_rollback = True   
    
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    # This ensures that any other menu screen is replaced.
    tag menu
    
    # The background of the main menu.
    window:
        style "mm_root"
        
        imagemap:
            
            ground "images/menus/mainmenu_ground.png"
            idle "images/menus/mainmenu_idle.png"
            hover "images/menus/mainmenu_hover.png"
            
            if persistent.unlocked:
                hotspot (343,375,452,417) action ShowMenu("unlocked")                            
                add "unlock"
            else:
                add "lock"
            
            hotspot (79,480,180,555) action Start()
            hotspot (259,480,353,555) action ShowMenu("load")
            hotspot (418,480,559,555) action ShowMenu("preferences")
            hotspot (617,480,715,555) action Quit(confirm=False)
            
init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98
        
        has vbox
 
        textbutton _("Return") action Return()
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Help") action Help()
        textbutton _("Quit") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    imagemap:
        ground "images/menus/blank_ground.png"  
        idle "images/menus/menubar_idle.png"
        selected_idle "images/menus/menubar_selected.png"
        insensitive "images/menus/menubar_insensitive.png"
        hover "images/menus/menubar_hover.png"
    
        hotspot (65,557,145,35) action Return()
        hotspot (226,557,100,37) action ShowMenu("save")
        hotspot (345,560,100,37) action ShowMenu("load")
        hotspot (467,559,150,37) action ShowMenu("preferences")
        hotspot (643,561,90,37) action Quit()    
    
    
    frame:            
        style "file_picker_frame"
        ypos 50
        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    # Format the description, and add it as text.
                    $ description = "% 2s. %s\n%s" % (
                        FileSlotName(i, columns * rows),
                        FileTime(i, empty=_("Empty Slot.")),
                        FileSaveName(i))

                    text description

                    key "save_delete" action FileDelete(i)
                    
                   
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    #use navigation
    use file_picker
    add "images/menus/save.png"

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    #use navigation   
    use file_picker
    add "images/menus/load.png"

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)

    

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces
    
screen preferences:

    tag menu

    # Include the navigation.
    #use navigation
    
     
    imagemap:
        ground "images/menus/options_ground.png"  
        idle "images/menus/menubar_idle.png"
        selected_idle "images/menus/menubar_selected.png"
        insensitive "images/menus/menubar_insensitive.png"
        hover "images/menus/menubar_hover.png"
        
        hotspot (65,557,145,35) action Return()
        hotspot (226,557,100,37) action ShowMenu("save")
        hotspot (345,560,100,37) action ShowMenu("load")
        hotspot (467,559,150,37) action ShowMenu("preferences")
        hotspot (643,561,90,37) action Quit()     
    
    # Put the navigation columns in a three-wide grid.
    grid 2 1:
        style_group "prefs"
        xfill True
        xmaximum 500
        xpos 200
        ypos 50

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")
                
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"               

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")
                
init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"
        background "images/menus/yesno.png"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 0.5
        yalign 1.0

        textbutton _("Q.Save") action QuickSave()
        textbutton _("Q.Load") action QuickLoad()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Skip") action Skip()
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    style.quick_button_text.outlines = [(1, "#000000")]
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    
##################################################

screen unlocked:
    tag menu
    
    imagemap:
        ground "images/menus/unlocked_ground.png"       
        idle "images/menus/unlocked_idle.png"
        hover "images/menus/unlocked_hover.png"
        
        if persistent.ending1:
            hotspot (201,12,250,60) action Start("ending1")
        if persistent.ending2:
            hotspot (203,84,250,60) action Start("ending2")
        if persistent.ending3:
            hotspot (203,154,250,60) action Start("ending3")
        if persistent.ending4:
            hotspot (199,223,250,60) action Start("ending4")
        if persistent.ending5:
            hotspot (199,297,250,60) action Start("ending5")
        if persistent.ending6:
            hotspot (184,360,250,60) action Start("ending6")
        if persistent.ending7:
            hotspot (197,434,250,60) action Start("ending7")
        if persistent.ending8:
            hotspot (194,501,250,60) action Start("ending8")
            
        hotspot (468,567,800,600) action ShowMenu("main_menu")
        
        if persistent.endings == 1:
            add "images/percent/125.png" at percent
        if persistent.endings == 2:
            add "images/percent/25.png" at percent
        if persistent.endings == 3:
            add "images/percent/375.png" at percent
        if persistent.endings == 4:
            add "images/percent/50.png" at percent
        if persistent.endings == 5:
            add "images/percent/625.png" at percent
        if persistent.endings == 6:
            add "images/percent/75.png" at percent
        if persistent.endings == 7:
            add "images/percent/875.png" at percent
        if persistent.endings == 8:
            add "images/percent/100.png" at percent            
        
        if persistent.complete:
            add "images/menus/luckyspecialapproves.png" xalign 0.8 yalign 0.7
                
        
init python:    
    def unlocked_banner():
        import webbrowser
        webbrowser.open_new('http://www.renpy.org')
